Module matcher

Module matcher 

Structs

MatcherOptions
Options for combined pattern matching
PatternMatcher
Combined pattern matcher that integrates glob and gitignore patterns
PatternMatcherBuilder
Builder for creating pattern matchers with a fluent API

Enums

MatchResult
Combined pattern matching result